#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2025/8/19 15:43
# @Author : 桐
# @QQ:1041264242
# 注意事项：
from app.core.tpl import tpl_env


def get_related_keyword_prompt(Keyword):
    template = tpl_env.get_template("prompt/get_related_keyword_prompt.tpl")
    return template.render(Keyword=Keyword)


def llm_base_prompt():
    llm_base_prompt = "You are a research expert whose primary goal is to identify promising, new, and key scientific problems based on existing scientific literature, in order to aid researchers in discovering novel and significant research opportunities that can advance the field."
    return llm_base_prompt


def fact_extraction_prompt():
    template = tpl_env.get_template("prompt/fact_extraction_prompt.tpl")
    return template.render()


def hypothesis_generate_prompt(Keyword, Known_Information):
    template = tpl_env.get_template("prompt/hypothesis_generate_prompt.tpl")
    return template.render(Keyword=Keyword, Known_Information=Known_Information)


def hypotheses_prompt(Hypotheses):
    hypotheses_index = 0
    hypotheses_prompt = ""
    for hypothesis in Hypotheses:
        # print(f"Hypothesis {hypotheses_index}:{hypothesis}\n")
        hypotheses_index += 1
        hypotheses_prompt += f"\nHypothesis {hypotheses_index}: {hypothesis}"
    print(f"\033[1;32m | INFO     | The hypoyjese prompt is：{hypotheses_prompt} \033[0m")

    return hypotheses_index, hypotheses_prompt


def paper_compression_prompt():
    template = tpl_env.get_template("prompt/paper_compression_prompt.tpl")
    return template.render()


def extract_entity_prompt():
    template = tpl_env.get_template("prompt/extract_entity_prompt.tpl")
    return template.render()


def initial_idea_prompt(hypotheses_prompt, title_abstract_prompt, keyword_str, hypotheses_index, index, keynum):
    template = tpl_env.get_template("prompt/initial_idea_prompt.tpl")
    data = {
        "hypotheses_prompt": hypotheses_prompt,
        "title_abstract_prompt": title_abstract_prompt,
        "keyword_str": keyword_str,
        "hypotheses_index": hypotheses_index,
        "index": index,
        "keynum": keynum,
    }
    return template.render(**data)


def extract_tec_entities_prompt():
    template = tpl_env.get_template("prompt/extract_tec_entities_prompt.tpl")
    return template.render()


def technical_optimizatio_prompt(title, title_abstract_prompt, Initial_Idea_Result):
    template = tpl_env.get_template("prompt/technical_optimizatio_prompt.tpl")
    data = {
        "title": title,
        "title_abstract_prompt": title_abstract_prompt,
        "Initial_Idea_Result": Initial_Idea_Result,
    }
    return template.render(**data)


def review_mechanism_prompt():
    template = tpl_env.get_template("prompt/review_mechanism_prompt.tpl")
    return template.render()


def MoA_based_optimization_prompt(target_next_optimization, optimization_keywords, title_abstract_prompt, draft):
    template = tpl_env.get_template("prompt/MoA_based_optimization_prompt.tpl")
    data = {
        "target_next_optimization": target_next_optimization,
        "optimization_keywords": optimization_keywords,
        "title_abstract_prompt": title_abstract_prompt,
        "draft": draft,
    }
    return template.render(**data)


def human_ai_collaboration_prompt(target_next_optimization, optimization_keywords, title_abstract_prompt, draft):
    template = tpl_env.get_template("prompt/human_ai_collaboration_prompt.tpl")
    data = {
        "target_next_optimization": target_next_optimization,
        "optimization_keywords": optimization_keywords,
        "title_abstract_prompt": title_abstract_prompt,
        "draft": draft,
    }
    return template.render(**data)



"""
    paper模块路由入口
"""
from fastapi import APIRouter

from app.api.paper import paper_api

paper_module_router = APIRouter(prefix="/paper")

paper_module_router.include_router(paper_api.router, tags=["论文助手模块"])



import json
from typing import ClassVar

from fastapi.encoders import jsonable_encoder
from pydantic import BaseModel
from starlette import status
from starlette.responses import JSONResponse, StreamingResponse


class ErrorAPIResponse(BaseModel):
    """
        API错误响应内容
    """
    code: int
    message: str
    data: dict = {}


class SuccessAPIResponse(BaseModel):
    """
        API成功响应内容
    """
    code: int = 200
    message: str = 'success'
    data: dict = {}


class StreamAPIResponse(BaseModel):
    """
        stream流式响应内容
    """

    HEADERS: ClassVar[dict] = {
        "Cache-Control": "no-cache",
        "Connection": "keep-alive"
    }
    MEDIA_TYPE: ClassVar[str] = "text/event-stream"

    @staticmethod
    async def error_stream_gen():
        """
            错误stream流返回信息
        """
        error_message = {
            "choices": [{"delta": {"role": "assistant", "content": "当前操作无法完成，请稍后再试"}}]}
        chunks = [
            f"data: {json.dumps(error_message, ensure_ascii=False)}\n\n",  # 错误消息
            "data: [DONE]\n\n"
        ]
        for chunk in chunks:
            yield chunk.encode()


class BaseAPI(object):
    """
        基础API接口类
    """

    @staticmethod
    def success(data: any, message: str = "success", code: int = 200, status_code: int = status.HTTP_200_OK):
        return JSONResponse(
            content=jsonable_encoder(SuccessAPIResponse(data=data, code=code, message=message)),
            status_code=status_code
        )

    @staticmethod
    def error(code: int, message: str, status_code: int, data: dict = None):
        if data is None:
            data = {}
        return JSONResponse(
            content=jsonable_encoder(ErrorAPIResponse(code=code, message=message, data=data)),
            status_code=status_code
        )

    @staticmethod
    def success_stream_response(stream_gen, **kwargs):
        return StreamingResponse(stream_gen,
                                 media_type=StreamAPIResponse.MEDIA_TYPE,
                                 headers=StreamAPIResponse.HEADERS,
                                 **kwargs)

    @staticmethod
    def error_stream_response(**kwargs):
        return StreamingResponse(StreamAPIResponse.error_stream_gen(),
                                 media_type=StreamAPIResponse.MEDIA_TYPE,
                                 headers=StreamAPIResponse.HEADERS,
                                 **kwargs)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2024/7/7 14:06
# @Author : 桐
# @QQ:1041264242
# 注意事项：

import json
import re
import time
import requests
from app.core.config import Proxies


# 用于获取Wikipedia上的简介内容
def remove_html_tags(text):
    clean = re.compile('<.*?>')
    return re.sub(clean, '', text)


def get_description(text):
    descriptions = []

    try:
        for item in text['search']:
            descriptions.append(item['description'])
        # print(descriptions)
    except:
        print("description is null !")

    # print("get_description ok!")
    return descriptions


def get_wikipedia_intro(entity_data, lang):
    wikipedia_intro = ''
    if 'sitelinks' in entity_data and f'{lang}wiki' in entity_data['sitelinks']:
        wikipedia_title = entity_data['sitelinks'][f'{lang}wiki']['title']
        wikipedia_url = 'https://en.wikipedia.org/w/api.php' if lang == 'en' else 'https://zh.wikipedia.org/w/api.php'
        wikipedia_params = {
            'action': 'query',
            'format': 'json',
            'titles': wikipedia_title,
            'prop': 'extracts',
            'exintro': True,
            'explaintext': True,
            'converttitles': True
        }
        while True:
            try:
                wikipedia_response = requests.get(wikipedia_url, wikipedia_params)
                break
            except requests.exceptions.RequestException as e:
                print("获取Wikipedia文章内容错误，等待60s后重试...")
                time.sleep(60)

        wikipedia_data = wikipedia_response.json()
        page_id = next(iter(wikipedia_data['query']['pages']))
        wikipedia_intro = wikipedia_data['query']['pages'][page_id]['extract']
        wikipedia_intro = remove_html_tags(wikipedia_intro)
    return wikipedia_intro


def search(query, language='en', limit=3):
    url = "https://www.wikidata.org/w/api.php"

    params = {
        'action': 'wbsearchentities',
        'format': 'json',
        'search': {query},  # 搜索文本
        'language': {language},  # 查询语言（英文）
        'type': 'item',
        'limit': {limit}  # 返回最大数目
    }

    # 访问
    get = requests.get(url=url, params=params, proxies=Proxies)
    # 转为json数据
    re_json = get.json()

    return re_json


def search_detailed(id, language='en'):
    url = "https://www.wikidata.org/w/api.php"

    params = {
        'ids': {id},  # 实体id,可多个，比如'Q123|Q456'
        'action': 'wbgetentities',
        'format': 'json',
        'language': {language},
    }

    # 访问
    get = requests.get(url=url, params=params, proxies=Proxies)
    # 转为json数据
    re_json = get.json()

    print(json.dumps(re_json["entities"][id]["descriptions"]["en"], ensure_ascii=False, indent=2))

    return re_json

# print(get_description(search("Astrophysics",limit=1)))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2024/11/2 19:08
# @Author : 桐
# @QQ:1041264242
# 注意事项：
import agentscope
from agentscope import msghub
from agentscope.agents import DialogAgent, UserAgent
from agentscope.message import Msg
from app.core.config import OUTPUT_PATH
import os
from app.core.tpl import tpl_env

model_configs = [
    {
        "config_name": "qwen-max-2025-01-25",
        "model_type": "dashscope_chat",
        "model_name": "qwen-max",
        "api_key": "sk-586f6f96d2704df6901e31de27fda2fe",
    },
    {
        "config_name": "qwen-plus",
        "model_type": "dashscope_chat",
        "model_name": "qwen-plus",
        "api_key": "sk-586f6f96d2704df6901e31de27fda2fe",
    },
    {
        "config_name": "glm-4-long",
        "model_type": "openai_chat",
        "model_name": "glm-4-long",
        "api_key": "1cf7ad6057486482907576343cdfad25.Pj3NWFDgjyjNqDVK",
        "client_args": {
            "base_url": "https://open.bigmodel.cn/api/paas/v4/",
        },
    },
    {
        "config_name": "deepseek-chat",
        "model_type": "openai_chat",
        "model_name": "deepseek-chat",
        "api_key": "sk-80cc66e836004e6ca698eb35206dd418",
        "client_args": {
            "base_url": "https://api.deepseek.com/v1",
        },
    },
    {
        "config_name": "moonshot-v1-8k",
        "model_type": "openai_chat",
        "model_name": "moonshot-v1-8k",
        "api_key": "sk-u66x82yZ6tMcjRMOwkKouZDHrhrLmLGl3ghjOlxOBUuvw6MD",
        "client_args": {
            "base_url": "https://api.moonshot.cn/v1",
        },
    },
    {
        "config_name": "gemini-2.5-flash",
        "model_type": "gemini_chat",
        "model_name": "gemini-2.5-flash",
        "api_key": "AIzaSyCRuZMYqpQZAt7wlSsqXGjXcwxUekrrH4s",
    },
    {
        "config_name": "hunyuan-large",
        "model_type": "openai_chat",
        "model_name": "hunyuan-large",
        "api_key": "sk-O5wisGpuwAS6FM7ICWtOM049vWYyEGq3opa4wSf920zeimW4",
        "client_args": {
            "base_url": "https://api.hunyuan.cloud.tencent.com/v1",
        },
    }
    # {
    #     "config_name": "chatgpt-4o-latest",
    #     "model_type": "openai_chat",
    #     "model_name": "chatgpt-4o-latest",
    #     "api_key": "sk-gT9nO93CQQKoNb1KTUuGIeV1b05DUkYF0ZJjngcDev12RiuY",
    #
    #     "client_args": {
    #         "base_url": "https://api.openai-proxy.org/v1/",
    #     },
    # },
]


def moa_idea_iteration(topic="", user_prompt="", user_id="", task=None):

    file_path_prefix = fr"{OUTPUT_PATH}/{user_id}/{task.id}/{topic}/MOA"
    # 读取模型配置
    agentscope.init(model_configs=model_configs)

    system_prompt = "You are a research expert whose primary goal is to identify promising, new, and key scientific problems based on existing scientific literature, in order to aid researchers in discovering novel and significant research opportunities that can advance the field."

    # 创建一个对话智能体和一个用户智能体
    dialogAgent_Gemini = DialogAgent(name="Gemini", model_config_name="glm-4-long", sys_prompt=system_prompt)
    dialogAgent_Qwen = DialogAgent(name="Qwen", model_config_name="qwen-plus", sys_prompt=system_prompt)
    dialogAgent_DeepSeek = DialogAgent(name="DeepSeek", model_config_name="deepseek-chat", sys_prompt=system_prompt)

    dialogAgent_AC = DialogAgent(name="AC", model_config_name="deepseek-chat", sys_prompt=system_prompt)

    dialogAgent_Reviewer = DialogAgent(name="Reviewer", model_config_name="deepseek-chat", sys_prompt=system_prompt)

    Gemini_message = dialogAgent_Gemini(Msg(name="User", role="user", content=user_prompt))
    Qwen_message = dialogAgent_Qwen(Msg(name="User", role="user", content=user_prompt))
    DeepSeek_message = dialogAgent_DeepSeek(Msg(name="User", role="user", content=user_prompt))

    os.makedirs(file_path_prefix, exist_ok=True)
    with open(fr"{file_path_prefix}/Qwen_{topic}_moa.md", 'w', encoding='utf-8') as f:
        f.write(Qwen_message.content)
    with open(fr"{file_path_prefix}/DeepSeek_{topic}_moa.md", 'w', encoding='utf-8') as f:
        f.write(DeepSeek_message.content)
    with open(fr"{file_path_prefix}/Kimi_{topic}_moa.md", 'w', encoding='utf-8') as f:
        f.write(Gemini_message.content)

    aggregation_tpl = tpl_env.get_template("prompt/moa/moa_idea_iteration_aggregation.tpl")
    data = {
        "Qwen_message": Qwen_message.content,
        "DeepSeek_message": DeepSeek_message.content,
        "Gemini_message": Gemini_message.content,
    }
    aggregation = aggregation_tpl.render(data=data)

    AC_message = dialogAgent_AC(Msg(name="User", role="user", content=aggregation))

    with open(fr"{file_path_prefix}/AC_{topic}_moa.md", 'w', encoding='utf-8') as f:
        f.write(AC_message.content)

    reviewer_prompt_tpl = tpl_env.get_template("prompt/moa/reviewer_prompt.tpl")
    Reviewer_prompt = reviewer_prompt_tpl.render()

    Reviewer_message = dialogAgent_Reviewer(Msg(name="User", role="user", content=Reviewer_prompt))

    with open(fr"{file_path_prefix}/Reviewer_{topic}_moa.md", 'w', encoding='utf-8') as f:
        f.write(Reviewer_message.content)

    # 打印模型 API 的使用情况
    agentscope.print_llm_usage()

    return AC_message.content


def moa_model(model_configs, agent_list, topic, user_prompt, systeam_prompt, ac_prompt="", ac_systeam="", stage=""):
    """
    :param model_configs:
    :param agent_list:
     {
     main:
     helper:['llm1','llm2','llm3']
     }
    :param topic:
    :param user_prompt:
    :param systeam_prompt:
    :param aggregation_prompt:
    :return:
    """
    # 读取模型配置
    agentscope.init(model_configs=model_configs)
    system_prompt = ("You are an research expert whose primary goal "
                     "is to identify promising, new, and key scientific problems based on existing scientific "
                     "literature, in order to aid researchers in discovering novel and significant research "
                     "opportunities that can advance the field.")
    agents = {}

    for llm in agent_list['helper']:
        agent = DialogAgent(name=llm, model_config_name=llm, sys_prompt=system_prompt)
        agents[llm] = agent

    messages = {}
    for agent_key in agents:
        agent = agents[agent_key]
        message = agent(Msg(name="user", role="user", content=user_prompt))
        messages[agent_key] = message

    for message_key in messages:
        with open(
                fr"{OUTPUT_PATH}/{topic}/MOA/{message_key}_{topic}_{stage}.md",
                'w', encoding='utf-8') as f:
            f.write(messages[message_key].content)

    if ac_prompt != "" and agent_list['main'] != "":
        AC = DialogAgent(name="AC", model_config_name=agent_list['main'], sys_prompt=ac_systeam)
        AC_message = AC(Msg(name="user", role="user", content=ac_prompt))
        with open(
                fr"{OUTPUT_PATH}/{topic}/MOA/AC_{topic}_{stage}.md",
                'w', encoding='utf-8') as f:
            f.write(AC_message.content)

    # 打印模型 API 的使用情况
    agentscope.print_llm_usage()


def moa_table(model_configs=model_configs, topic='', draft='', user_id='', task=None):
    file_path_prefix = fr"{OUTPUT_PATH}/{user_id}/{task.id}/{topic}/MOA"
    # test_tpl = tpl_env.get_template("prompt/moa/moa_test.tpl")
    # draft = test_tpl.render()

    # agentscope.studio.init()
    agentscope.init(model_configs=model_configs)  # ,logger_level="DEBUG",save_log=True

    role = ("You are a seminar reviewer responsible for evaluating research idea drafts. When reviewing, take into "
            "account the content of the draft as well as feedback from other reviewers. While recognizing the value "
            "in others' comments, your focus should be on providing a unique perspective that enhances and optimizes "
            "the draft. Your feedback should be concise, consisting of a well-constructed paragraph that builds on "
            "the ongoing discussion without replicating other reviewers' suggestions. Always strive to present your "
            "distinct viewpoint.")
    viewer = """Act a moderator in a seminar.  After the four reviewers have completed their evaluations, 
    you will need to comprehensively analyze the content of the idea draft as well as the valuable review comments 
    provided by each reviewer. Based on this, you are required to systematically summarize and integrate these review 
    opinions, ensuring that all key feedback and suggestions are accurately and comprehensively considered. The 
    output should strictly follow the format below: # Overall Opinions:

    # Iterative Optimization Search Keywords:
    - [Keyword 1]
    - [Keyword 2]
    - ..."""

    dialogAgent_Qwen = DialogAgent(name="Reviewer 1", model_config_name="qwen-plus", sys_prompt=role)  #"qwen-max-0919"
    dialogAgent_Gemini = DialogAgent(name="Reviewer 2", model_config_name="glm-4-long",
                                     sys_prompt=role)  # "gemini-1.5-flash"
    dialogAgent_DeepSeek = DialogAgent(name="Reviewer 3", model_config_name="deepseek-chat", sys_prompt=role)
    # userAgent = UserAgent(name="Reviewer 4")

    dialogAgent_Viewer = DialogAgent(name="Viewer", model_config_name="deepseek-chat", sys_prompt=viewer)

    with msghub(participants=[dialogAgent_Gemini, dialogAgent_Qwen, dialogAgent_DeepSeek,
                              dialogAgent_Viewer]) as hub:
        # Broadcast a message to all participants
        hub.broadcast(Msg(name="Host", role="user",
                          content=f"Welcome to join the seminar chat! Now, The idea draft we need to discuss as "
                                  f"follows:\n{draft}"))

        dialogAgent_Qwen()
        dialogAgent_Gemini()
        dialogAgent_DeepSeek()
        # userAgent()
        viewer_message = dialogAgent_Viewer()

    with open(fr"{file_path_prefix}/{topic}_review_moa.md", 'w', encoding='utf-8') as f:
        f.write(viewer_message.content)

    # 打印模型 API 的使用情况
    agentscope.print_llm_usage()



"""
Main AstroInsight class for research paper generation
"""

import logging
import uuid
from pathlib import Path
from typing import Dict, List, Optional, Union

from ..utils.paper_generator import PaperGenerator
from .config import AstroInsightConfig

# 配置日志
logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)


class AstroInsight:
    """AstroInsight主类 - 提供研究论文生成的核心功能"""

    def __init__(self, config: AstroInsightConfig):
        """
        初始化AstroInsight

        Args:
            config: 配置对象
        """
        self.config = config
        self.task_id = self._generate_task_id()
        self.status = "initialized"
        self.result = None

        logger.info(f"AstroInsight initialized with task_id: {self.task_id}")

    def _generate_task_id(self) -> str:
        """生成唯一的任务ID"""
        return str(uuid.uuid4())

    def generate_paper(self) -> Dict[str, Union[str, List[str], str]]:
        """
        生成论文的主要方法

        Returns:
            包含任务信息的字典
        """
        try:
            self.status = "processing"
            logger.info(f"Starting paper generation for keyword: {self.config.keyword}")

            # 创建论文生成器
            generator = PaperGenerator(self.config)

            # 执行生成流程
            result = generator.generate()

            self.status = "completed"
            self.result = result

            logger.info(f"Paper generation completed successfully")

            return {
                "task_id": self.task_id,
                "steps": result.get("steps", []),
                "result_file": result.get("result_file", ""),
                "status": self.status,
                "keyword": self.config.keyword,
                "search_paper_num": self.config.search_paper_num,
            }

        except Exception as e:
            self.status = "failed"
            logger.error(f"Paper generation failed: {str(e)}")

            return {
                "task_id": self.task_id,
                "status": self.status,
                "error": str(e),
                "keyword": self.config.keyword,
            }

    def get_status(self) -> Dict[str, str]:
        """获取任务状态"""
        return {
            "task_id": self.task_id,
            "status": self.status,
            "keyword": self.config.keyword,
        }

    def get_result(self) -> Optional[Dict]:
        """获取任务结果"""
        return self.result

    def cancel(self) -> bool:
        """取消任务"""
        if self.status == "processing":
            self.status = "cancelled"
            logger.info(f"Task {self.task_id} cancelled")
            return True
        return False



from app.core.celery import celery_app
from main import main

@celery_app.task(bind=True)
def paper_assistant(task, keyword, search_paper_num):
    """
        celery异步任务
    """
    data = main(task, keyword, search_paper_num)
    return data



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2025/8/21 9:58
# @Author : 桐
# @QQ:1041264242
# 注意事项：

import json
import os
import re
import arxiv
import requests
from bs4 import BeautifulSoup
import urllib.parse
from scihub_cn.scihub import SciHub
from app.core.config import OUTPUT_PATH, Proxies


### 下载PDF的保存路径

def check_pdf(file_path):
    """
    检查PDF文件是否能正常打开。

    参数:
    file_path (str): PDF文件路径。

    返回:
    bool: 如果文件能正常打开则返回True，否则返回False。
    """
    try:
        with open(file_path, 'rb') as f:
            # 读取文件的前5个字节，PDF文件通常以"%PDF-"开头
            # 这里我们读取5个字节是因为"%PDF-"是5个字节（包括百分号）
            header = f.read(5)
            # 检查文件开头是否为"%PDF-"（PDF文件的魔数）
            if header != b'%PDF-':
                # 如果不是PDF开头，则抛出异常
                print("File does not start with PDF header.")
                return False
            # 如果需要，可以在这里添加更多的检查逻辑
            return True
    except Exception as e:
        print(f"Error opening PDF file {file_path}: {e}")
        return False


def sanitize_folder_name(folder_name):
    # 定义需要替换的违规字符集
    illegal_chars = r'<>:"/\\|\?*'
    # 使用正则表达式替换违规字符为下划线 _
    sanitized_name = re.sub(f'[{illegal_chars}]', '_', folder_name)
    return sanitized_name


def search_google_scholar(doi):
    # Google Scholar的搜索URL
    search_url = f"https://scholar.google.com/scholar?q={urllib.parse.quote(doi)}"

    # 模拟请求
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                      "Chrome/91.0.4472.124 Safari/537.36"
    }

    response = requests.get(search_url, headers=headers, proxies=Proxies)

    soup = BeautifulSoup(response.text, 'html.parser')

    # 查找包含[PDF]文本的链接
    pdf_links = []
    for link in soup.find_all('a'):
        if '[PDF]' in link.get_text():
            pdf_links.append(link['href'])

    # 输出找到的链接
    for pdf_link in pdf_links:
        print(pdf_link)
        return pdf_link


def download_pdf_from_google(pdf_url, title, output_path):
    save_path = f"{output_path}/{title}.pdf"

    # 发送HTTP GET请求来获取PDF文件
    response = requests.get(pdf_url, stream=True, proxies=Proxies)
    # response = requests.get(url, stream=True)
    # 检查请求是否成功
    response.raise_for_status()
    # 以二进制模式写入文件
    with open(save_path, 'wb') as f:
        for chunk in response.iter_content(chunk_size=8192):
            f.write(chunk)

    return save_path


def download_pdf_from_scihub(doi, output_path):
    sh = SciHub(proxy=Proxies)
    # save_path = sh.download({"doi": doi}, destination=output_path, is_translate_title=False)
    try:
        # 设置is_translate_title可将paper's title进行翻译后下载存储
        save_path = sh.download({"doi": doi}, destination=output_path, is_translate_title=False)
    except:
        save_path = None

    # print(result)
    return save_path


def download_pdf_from_unpaywall(doi, title, output_path, email="z1041264242@gmail.com"):
    print(f"\033[1;32m | INFO     | Getting paper from unpaywall: ... \033[0m")
    api_url = f"https://api.unpaywall.org/v2/{doi}?email={email}"
    response = requests.get(api_url, proxies=Proxies)

    if response.status_code == 200:
        data = response.json()
        oa_location = data.get("best_oa_location")
        if oa_location and oa_location.get("url_for_pdf"):
            pdf_url = oa_location["url_for_pdf"]
            pdf_data = requests.get(pdf_url)
            if pdf_data.status_code == 200:
                file_name = fr"{title}.pdf"
                file_path = os.path.join(output_path, file_name)
                with open(file_path, "wb") as f:
                    f.write(pdf_data.content)
                return file_path
    return None


def download_pdf_from_arxiv(doi, title, output_path):
    """
    根据 Titel 从 arXiv 下载 PDF（前提是该 DOI 有对应）
    """
    print(f"\033[1;32m | INFO     | Getting paper from ArXiv: ... \033[0m")

    search_engine = arxiv.Search(
        query=title,
        max_results=1,
        sort_by=arxiv.SortCriterion.Relevance
    )
    for result in search_engine.results():
        pdf_url = result.pdf_url
        pdf_doi = result.doi
        print(result.doi)
        print(pdf_url)
        print(doi)
        if pdf_doi == doi:
            print("ok")
            # 使用流式请求
            with requests.get(pdf_url, proxies=Proxies, stream=True) as r:
                if r.status_code == 200:
                    file_name = fr"{title}.pdf"
                    file_path = os.path.join(output_path, file_name)
                    with open(file_path, "wb") as f:
                        for chunk in r.iter_content(chunk_size=8192):  # 每次读8KB
                            if chunk:  # 过滤掉 keep-alive 块
                                f.write(chunk)
                    return file_path
    return None


def download_pdf_from_crossref(doi, title, output_path):
    url = f"https://api.crossref.org/works/{doi}"
    headers = {"Accept": "application/json"}
    r = requests.get(url, headers=headers, proxies=Proxies)

    if r.status_code == 200:
        data = r.json()
        # 获取 publisher-hosted PDF 链接（如果有）
        for link in data["message"].get("link", []):
            if link.get("content-type") == "application/pdf":
                pdf_url = link["URL"]
                print(pdf_url)
                pdf_data = requests.get(pdf_url)
                if pdf_data.status_code == 200:
                    file_name = fr"{title}.pdf"
                    file_path = os.path.join(output_path, file_name)
                    with open(file_path, "wb") as f:
                        f.write(pdf_data.content)
                    return file_path
    return None


def getdown_pdf_google_url(doi, title, output_path):
    print(f"\033[1;32m | INFO     | Getting paper from Google: ... \033[0m")

    pdf_url = search_google_scholar(doi)

    if pdf_url:
        print("找到PDF链接:", pdf_url)
        save_path = download_pdf_from_google(pdf_url, title, output_path)
        return save_path
    else:
        print("未找到PDF链接。")
        return False


def download_pdf_from_Giiisp(doi, title, output_path):
    """
    搜索论文API

    参数:
    search_query: 搜索关键词
    count: 搜索数量（最大200）
    sortOrder: 排序顺序 1-降序 2-升序
    sortBy: 排序方式 1-相关性 2-出版日期
    search_type: 搜索类型 1-标题/摘要 2-作者
    """
    print(f"\033[1;32m | INFO     | Getting paper from Giiisp: ... \033[0m")

    # API地址
    url = "https://giiisp.com/first/oaPaper/api/filter"

    # 请求参数
    payload = {
        "count": 5,
        "sortOrder": 1,
        "sortBy": 1,
        "searchQuery": title,
        "searchType": 1
    }

    # 请求头
    headers = {
        "Content-Type": "application/json",
        "Authorization": "85d7e5806950935fa3bf11f8e017c38f",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36"
    }

    try:
        # 发送POST请求
        response = requests.post(
            url,
            json=payload,
            headers=headers,
            timeout=30
        )

        # 检查响应状态
        response.raise_for_status()

        # 解析JSON响应
        result = response.json()

        if result['data'] != [] and result['data'][0]['giiispPdfUrl'] != None:
            # print(result)
            pattern = r"https?://(dx\.)?doi\.org/"
            pdf_url = result['data'][0]['giiispPdfUrl']
            pdf_doi = re.sub(pattern, "", result['data'][0]['doi'])

            if pdf_doi == doi:
                pdf_data = requests.get(pdf_url)
                if pdf_data.status_code == 200:
                    file_name = fr"{title}.pdf"
                    file_path = os.path.join(output_path, file_name)
                    with open(file_path, "wb") as f:
                        f.write(pdf_data.content)
                    return file_path
        return None

    except requests.exceptions.RequestException as e:
        print(f"请求错误: {e}")
        return None
    except json.JSONDecodeError as e:
        print(f"JSON解析错误: {e}")
        return None


def download_pdf(doi, title, output_path):
    """
    尝试通过多个方法下载 PDF 文件。
    成功则返回文件路径，失败则返回 None。
    """
    download_methods = [
        lambda: download_pdf_from_arxiv(doi, title, output_path),
        lambda: download_pdf_from_Giiisp(doi, title, output_path),
        lambda: download_pdf_from_unpaywall(doi, title, output_path),
        lambda: getdown_pdf_google_url(doi, title, output_path),
        lambda: download_pdf_from_scihub(doi, output_path),
    ]

    for method in download_methods:
        result = method()
        if result and check_pdf(result):
            print(f"\033[1;32m | INFO     | Getting paper: Success \033[0m")
            return result
        print(f"\033[1;31m | INFO     | Getting paper: Failed \033[0m")

    return None


def download_all_pdfs(dois, title, topic, user_id, task):
    """
    下载给定DOI列表中的PDF文件。

    参数:
    dois (list): 包含若干个DOI的列表。

    返回:
    list: 包含所有下载结果的列表，每个元素是对应DOI的下载结果信息。
    """

    output_path = fr"{OUTPUT_PATH}/{user_id}/{task.id}/{topic}/Paper/pdf"

    if not os.path.exists(output_path):
        os.makedirs(output_path)

    print(f"\033[1;32m | INFO     | Getting paper, doi:{dois}, title:{title} \033[0m")
    paper_pdf = download_pdf(dois, sanitize_folder_name(title), output_path)

    #返回的是下载后pdf的路径

    return paper_pdf


if __name__ == "__main__":
    print(os.environ)
    dois = '10.1088/1674-4527/19/9/133'
    download_all_pdfs(dois=dois, title='Pulsar Candidates Classification with Deep Convolutional Neural Networks',
                      topic='pulsar candidate classification')



from celery.result import AsyncResult
from fastapi import APIRouter, HTTPException, UploadFile, File, Depends
from sqlalchemy.orm import Session
from starlette import status

from app.api.common import BaseAPI
from app.core.celery import celery_app
from main import main
from app.task.paper_assistant import paper_assistant

router = APIRouter()


class RAGAPI(BaseAPI):
    """
    RAG API类，提供文档处理和查询接口
    """

    @staticmethod
    @router.post("/generate_paper",
                 summary="生成论文",
                 description="生成论文"
                 )
    async def generate_paper(Keyword: str):
        """
        生成论文

        Args:
            Keyword : 关键词

        Returns:
            创建结果响应
        """
        try:
            task = paper_assistant.delay(Keyword=Keyword, SearchPaperNum=2)
            return BaseAPI.success(data={"task_id": task.id})
        except ValueError as e:
            return BaseAPI.error(code=status.HTTP_400_BAD_REQUEST,
                                 message=str(e),
                                 status_code=status.HTTP_400_BAD_REQUEST)
        except Exception as e:
            return BaseAPI.error(code=status.HTTP_500_INTERNAL_SERVER_ERROR,
                                 message=f"内部服务器错误: {str(e)}",
                                 status_code=status.HTTP_500_INTERNAL_SERVER_ERROR)

    @staticmethod
    @router.post("/get_status",
                 summary="获取结果",
                 description="获取结果"
                 )
    async def generate_paper(task_id: str):
        """
        获取结果

        Args:
            task_id : 任务id

        Returns:
            创建结果响应
        """
        try:
            task_result = AsyncResult(task_id, app=celery_app)
            return BaseAPI.success(data={"task_result": task_result.result})
        except ValueError as e:
            return BaseAPI.error(code=status.HTTP_400_BAD_REQUEST,
                                 message=str(e),
                                 status_code=status.HTTP_400_BAD_REQUEST)
        except Exception as e:
            return BaseAPI.error(code=status.HTTP_500_INTERNAL_SERVER_ERROR,
                                 message=f"内部服务器错误: {str(e)}",
                                 status_code=status.HTTP_500_INTERNAL_SERVER_ERROR)



"""
Paper generator utility for AstroInsight
"""

import logging
import os
import sys
from typing import Any, Dict, List

# 添加原项目路径到sys.path
sys.path.append(os.path.join(os.path.dirname(__file__), "..", "..", ".."))

logger = logging.getLogger(__name__)


class PaperGenerator:
    """论文生成器类 - 封装原有的论文生成逻辑"""

    def __init__(self, config):
        """
        初始化论文生成器

        Args:
            config: AstroInsightConfig对象
        """
        self.config = config
        self.steps = []

    def generate(self) -> Dict[str, Any]:
        """
        执行论文生成流程

        Returns:
            包含生成结果的字典
        """
        try:
            # 模拟原有的main函数流程
            self.steps.append("Start Initial_Idea")
            initial_result = self._initial_idea()
            self.steps.append("End Initial_Idea")

            self.steps.append("Start Technical_Optimization")
            technical_result = self._technical_optimization(initial_result)
            self.steps.append("End Technical_Optimization")

            self.steps.append("Start MoA_Based_Optimization")
            moa_result = self._moa_based_optimization(technical_result)
            self.steps.append("End MoA_Based_Optimization")

            self.steps.append("Start Human_AI_Collaboration")
            final_result = self._human_ai_collaboration(moa_result)
            self.steps.append("End Human_AI_Collaboration")

            logger.info("Paper generation workflow completed successfully")

            return {
                "steps": self.steps,
                "result_file": final_result,
                "status": "completed",
            }

        except Exception as e:
            logger.error(f"Paper generation failed: {str(e)}")
            raise

    def _initial_idea(self) -> str:
        """初始想法生成阶段"""
        logger.info("Generating initial idea...")
        # 这里应该调用原有的Initial_Idea函数
        # 暂时返回模拟结果
        return f"{self.config.output_path}/initial_idea_result.md"

    def _technical_optimization(self, initial_result: str) -> str:
        """技术优化阶段"""
        logger.info("Performing technical optimization...")
        # 这里应该调用原有的Technical_Optimization函数
        return f"{self.config.output_path}/technical_optimization_result.md"

    def _moa_based_optimization(self, technical_result: str) -> str:
        """MoA基础优化阶段"""
        logger.info("Performing MoA-based optimization...")
        # 这里应该调用原有的MoA_Based_Optimization函数
        return f"{self.config.output_path}/moa_optimization_result.md"

    def _human_ai_collaboration(self, moa_result: str) -> str:
        """人机协作优化阶段"""
        logger.info("Performing human-AI collaboration...")
        # 这里应该调用原有的Human_AI_Collaboration函数
        return f"{self.config.output_path}/final_result.md"



"""
Convenience functions for AstroInsight
"""

from typing import Any, Dict

from ..core.astroinsight import AstroInsight
from ..core.config import AstroInsightConfig


def generate_paper(keyword: str, search_paper_num: int = 2, **kwargs) -> Dict[str, Any]:
    """
    便捷的论文生成函数

    Args:
        keyword: 研究关键词
        search_paper_num: 搜索论文数量
        **kwargs: 其他配置参数

    Returns:
        包含生成结果的字典

    Example:
        >>> result = generate_paper("machine learning", 3)
        >>> print(f"Task ID: {result['task_id']}")
    """
    # 创建配置
    config = AstroInsightConfig(
        keyword=keyword, search_paper_num=search_paper_num, **kwargs
    )

    # 创建AstroInsight实例
    astro = AstroInsight(config)

    # 执行生成
    return astro.generate_paper()


def generate_paper_async(keyword: str, search_paper_num: int = 2, **kwargs) -> str:
    """
    异步论文生成函数（返回任务ID）

    Args:
        keyword: 研究关键词
        search_paper_num: 搜索论文数量
        **kwargs: 其他配置参数

    Returns:
        任务ID字符串

    Example:
        >>> task_id = generate_paper_async("AI research", 2)
        >>> print(f"Task started: {task_id}")
    """
    # 创建配置
    config = AstroInsightConfig(
        keyword=keyword, search_paper_num=search_paper_num, **kwargs
    )

    # 创建AstroInsight实例
    astro = AstroInsight(config)

    # 返回任务ID
    return astro.task_id



"""
Configuration classes for AstroInsight
"""

import os
from dataclasses import dataclass
from pathlib import Path
from typing import Optional


@dataclass
class AstroInsightConfig:
    """配置类 - 用于AstroInsight的主要配置"""

    keyword: str
    search_paper_num: int = 2
    user_id: str = "default_user"
    compression: bool = True
    output_path: str = "./temp"

    def __post_init__(self):
        """初始化后处理"""
        # 确保输出路径存在
        Path(self.output_path).mkdir(parents=True, exist_ok=True)

        # 验证参数
        if self.search_paper_num <= 0:
            raise ValueError("search_paper_num must be positive")
        if not self.keyword.strip():
            raise ValueError("keyword cannot be empty")


@dataclass
class APIConfig:
    """API配置类"""

    # 大模型API配置
    mineru_api_token: Optional[str] = None
    qwen_api_token: Optional[str] = None
    deepseek_api_token: Optional[str] = None
    deepseek_api_base_url: str = "https://api.deepseek.com/v1"

    # 数据库配置
    neo4j_username: Optional[str] = None
    neo4j_password: Optional[str] = None
    neo4j_host: str = "localhost"
    neo4j_port: str = "7687"

    # Redis配置
    redis_server: str = "127.0.0.1"
    redis_port: int = 6379
    redis_password: Optional[str] = None
    redis_db_index: int = 0

    def __post_init__(self):
        """从环境变量加载配置"""
        self.mineru_api_token = self.mineru_api_token or os.getenv("MINERU_API_TOKEN")
        self.qwen_api_token = self.qwen_api_token or os.getenv("QWEN_API_TOKEN")
        self.deepseek_api_token = self.deepseek_api_token or os.getenv(
            "DEEPSEEK_API_TOKEN"
        )
        self.neo4j_username = self.neo4j_username or os.getenv("NEO4J_USERNAME")
        self.neo4j_password = self.neo4j_password or os.getenv("NEO4J_PASSWORD")
        self.redis_password = self.redis_password or os.getenv("REDIS_PASSWORD")



"""
Command line interface for AstroInsight
"""

import json
from pathlib import Path

import click

from .api.paper_api import PaperAPI
from .core.astroinsight import AstroInsight
from .core.config import AstroInsightConfig


@click.group()
@click.version_option(version="0.1.0")
def cli():
    """AstroInsight - AI-powered research paper assistant"""
    pass


@cli.command()
@click.option("--keyword", "-k", required=True, help="研究关键词")
@click.option("--papers", "-p", default=2, help="搜索论文数量", type=int)
@click.option("--user-id", "-u", default="default", help="用户ID")
@click.option("--output", "-o", default="./temp", help="输出路径")
@click.option("--compression/--no-compression", default=True, help="是否启用论文压缩")
def generate(keyword, papers, user_id, output, compression):
    """生成研究论文"""
    try:
        click.echo(f"🚀 开始生成论文...")
        click.echo(f"📝 关键词: {keyword}")
        click.echo(f"📊 论文数量: {papers}")
        click.echo(f"👤 用户ID: {user_id}")
        click.echo(f"📁 输出路径: {output}")
        click.echo(f"🗜️  压缩: {'启用' if compression else '禁用'}")
        click.echo("-" * 50)

        # 创建配置
        config = AstroInsightConfig(
            keyword=keyword,
            search_paper_num=papers,
            user_id=user_id,
            compression=compression,
            output_path=output,
        )

        # 创建AstroInsight实例
        astro = AstroInsight(config)

        # 执行生成
        with click.progressbar(length=4, label="生成进度") as bar:
            result = astro.generate_paper()
            bar.update(4)

        click.echo("✅ 论文生成完成！")
        click.echo(f"🆔 任务ID: {result['task_id']}")
        click.echo(f"📄 结果文件: {result['result_file']}")
        click.echo(f"📋 执行步骤: {len(result['steps'])} 步")

        # 显示步骤详情
        for i, step in enumerate(result["steps"], 1):
            click.echo(f"  {i}. {step}")

    except Exception as e:
        click.echo(f"❌ 生成失败: {str(e)}", err=True)
        raise click.Abort()


@cli.command()
@click.option("--keyword", "-k", required=True, help="研究关键词")
@click.option("--papers", "-p", default=2, help="搜索论文数量", type=int)
@click.option("--user-id", "-u", default="default", help="用户ID")
@click.option("--output", "-o", default="./temp", help="输出路径")
def generate_async(keyword, papers, user_id, output):
    """异步生成研究论文（返回任务ID）"""
    try:
        click.echo(f"🚀 创建异步论文生成任务...")
        click.echo(f"📝 关键词: {keyword}")
        click.echo(f"📊 论文数量: {papers}")

        # 创建API实例
        api = PaperAPI()

        # 创建异步任务
        response = api.generate_paper_async(
            keyword=keyword,
            search_paper_num=papers,
            user_id=user_id,
            output_path=output,
        )

        if response["success"]:
            click.echo("✅ 异步任务创建成功！")
            click.echo(f"🆔 任务ID: {response['data']['task_id']}")
            click.echo(f"📊 状态: {response['data']['status']}")
            click.echo(f"💡 提示: 使用 'astroinsight status <task_id>' 查询进度")
        else:
            click.echo(f"❌ 任务创建失败: {response['message']}", err=True)

    except Exception as e:
        click.echo(f"❌ 操作失败: {str(e)}", err=True)
        raise click.Abort()


@cli.command()
@click.argument("task_id")
def status(task_id):
    """查询任务状态"""
    try:
        click.echo(f"🔍 查询任务状态: {task_id}")

        # 创建API实例
        api = PaperAPI()

        # 查询状态
        response = api.get_status(task_id)

        if response["success"]:
            click.echo("✅ 状态查询成功！")
            click.echo(f"🆔 任务ID: {response['data']['task_id']}")
            click.echo(f"📊 状态: {response['data']['status']}")
            if "message" in response["data"]:
                click.echo(f"💬 消息: {response['data']['message']}")
        else:
            click.echo(f"❌ 状态查询失败: {response['message']}", err=True)

    except Exception as e:
        click.echo(f"❌ 查询失败: {str(e)}", err=True)
        raise click.Abort()


@cli.command()
@click.option("--keyword", "-k", required=True, help="研究关键词")
@click.option("--papers", "-p", default=2, help="搜索论文数量", type=int)
@click.option("--user-id", "-u", default="default", help="用户ID")
@click.option("--output", "-o", default="./temp", help="输出路径")
@click.option(
    "--format",
    "-f",
    default="text",
    type=click.Choice(["text", "json"]),
    help="输出格式",
)
def analyze(keyword, papers, user_id, output, format):
    """分析研究领域（不生成论文）"""
    try:
        click.echo(f"🔍 开始分析研究领域...")
        click.echo(f"📝 关键词: {keyword}")
        click.echo(f"📊 论文数量: {papers}")

        # 这里可以添加领域分析逻辑
        analysis_result = {
            "keyword": keyword,
            "paper_count": papers,
            "analysis": "研究领域分析功能正在开发中...",
        }

        if format == "json":
            click.echo(json.dumps(analysis_result, indent=2, ensure_ascii=False))
        else:
            click.echo("📊 分析结果:")
            click.echo(f"  关键词: {analysis_result['keyword']}")
            click.echo(f"  论文数量: {analysis_result['paper_count']}")
            click.echo(f"  分析: {analysis_result['analysis']}")

    except Exception as e:
        click.echo(f"❌ 分析失败: {str(e)}", err=True)
        raise click.Abort()


@cli.command()
def config():
    """显示当前配置"""
    try:
        click.echo("⚙️  AstroInsight 配置信息")
        click.echo("=" * 40)

        # 显示环境变量配置
        import os

        config_vars = [
            "MINERU_API_TOKEN",
            "QWEN_API_TOKEN",
            "DEEPSEEK_API_TOKEN",
            "NEO4J_USERNAME",
            "NEO4J_PASSWORD",
            "REDIS_PASSWORD",
        ]

        for var in config_vars:
            value = os.getenv(var, "未设置")
            if var.endswith("_TOKEN") or var.endswith("_PASSWORD"):
                value = "***" if value != "未设置" else value
            click.echo(f"{var}: {value}")

        click.echo("=" * 40)
        click.echo("💡 提示: 在 .env 文件中设置这些环境变量")

    except Exception as e:
        click.echo(f"❌ 配置查询失败: {str(e)}", err=True)


def main():
    """主函数入口"""
    cli()


if __name__ == "__main__":
    main()



"""
AstroInsight - AI-powered research paper assistant with multi-agent collaboration

A comprehensive tool for research paper analysis, hypothesis generation,
and multi-agent collaborative optimization.
"""

from .api.paper_api import PaperAPI
from .core.astroinsight import AstroInsight
from .core.config import AstroInsightConfig
from .utils.generator import generate_paper

__version__ = "0.1.0"
__author__ = "AstroInsight Team"
__email__ = "contact@astroinsight.com"

__all__ = [
    "AstroInsight",
    "AstroInsightConfig",
    "PaperAPI",
    "generate_paper",
]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2025/8/19 16:08
# @Author : 桐
# @QQ:1041264242
# 注意事项：
import os
import re

from app.core.prompt import get_related_keyword_prompt, paper_compression_prompt, extract_entity_prompt, \
    extract_tec_entities_prompt, review_mechanism_prompt
from app.utils.llm_api import call_with_deepseek, call_with_deepseek_jsonout, call_with_qwenmax
from app.utils.arxiv_api import search_paper
from app.utils.scholar_download import download_all_pdfs
from app.utils.pdf_to_md import pdf2md_mineruapi
from app.utils.wiki_search import get_description, search
from app.core.config import OUTPUT_PATH, graph
import ast


def SearchKeyWordScore(Keywords):
    print(f"\033[1;32m | INFO     | calculate Keyword score... \033[0m")

    for index, keyword in enumerate(Keywords):
        entity = keyword['entity']

        # 定义Cypher查询语句
        query = f"""
        MATCH (n:Words)
        WHERE n.other CONTAINS '\\'{entity}\\'' OR n.name = '{entity}'
        RETURN n.count,n
        ORDER BY n.count DESC
        LIMIT 1
        """

        # 执行查询并获取结果
        nodes = graph.run(query).data()

        if len(nodes) != 0:
            Keywords[index]['count'] = nodes[0]['n.count']
        else:
            Keywords[index]['count'] = 0

    # 计算最小和最大count值
    min_count = min(item['count'] for item in Keywords)
    max_count = max(item['count'] for item in Keywords)

    # 权重分配
    weight_importance = 0.4
    weight_count = 0.6

    # 计算综合得分
    for item in Keywords:
        normalized_count = (item['count'] - min_count) / (max_count - min_count)
        composite_score = (item['importance_score'] * weight_importance) + (normalized_count * weight_count)
        item['composite_score'] = composite_score

        # 排序并输出结果（可选）
    sorted_data = sorted(Keywords, key=lambda x: x['composite_score'], reverse=True)

    print(f"\033[1;32m | INFO     | calculate Keyword score:OK!\n{sorted_data} \033[0m")

    return sorted_data


def get_related_keyword(Keyword):
    print(f"\033[1;32m | INFO     | geting related keyword... \033[0m")
    user_prompt = get_related_keyword_prompt(Keyword=Keyword)
    result = call_with_deepseek(system_prompt="You are a helpful assistant.", question=user_prompt)

    print(f"\033[1;32m | INFO     | The related keyword is :{result} \033[0m")

    print(f"\033[1;32m | INFO     | geting related keyword:OK! \033[0m")

    return ast.literal_eval(result)


def remove_number_prefix(paragraph):
    # # 定义一个正则表达式模式，用于匹配句子开头的数字和随后的句点空格
    # pattern = r'^\d+\. '
    # # 利用re.sub函数，将匹配到的部分替换为空字符串，以此移除它
    # modified_sentence = re.sub(pattern, '', sentence)
    # return modified_sentence
    # 定义一个正则表达式模式，用于匹配句子开头的数字和随后的句点空格
    pattern = r'^\d+\. |(?<=\n)\d+\. '
    # 利用re.sub函数，将匹配到的部分替换为空字符串，以此移除它
    modified_paragraph = re.sub(pattern, '', paragraph, flags=re.MULTILINE)
    return modified_paragraph


def read_markdown_file(file_path):
    """
    读取指定Markdown文件的内容，并将其打印到控制台。

    参数:
    file_path (str): Markdown文件的路径。
    """

    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            content = file.read()
            return content

    except FileNotFoundError:
        print(f"\033[1;31m | ERRO     | file can't find: {file_path} \033[0m")
    except IOError as e:
        print(f"\033[1;31m | ERRO     | load file erro: {e} \033[0m")


def extract_hypothesis(file, split_section="Hypothesis"):
    print(f"\033[1;32m | INFO     | extract hypothesis... \033[0m")

    text = read_markdown_file(file)

    # 正则表达式匹配 Hypothesis 后的内容
    pattern = re.compile(fr"{split_section} \d+:(.+?)\n", re.DOTALL)

    # 查找所有匹配项
    matches = pattern.findall(text)

    # 去除每个匹配项前后的空白字符
    hypotheses = [match.strip() for match in matches]

    # # 打印结果
    # for i, hypothesis in enumerate(hypotheses, start=1):
    #     print(f"Hypothesis {i}:\n{hypothesis}\n")

    return hypotheses


def paper_compression(doi, title, topic, user_id, task):
    paper_pdf_path = download_all_pdfs(dois=doi, title=title, topic=topic, user_id=user_id, task=task)
    file_path_prefix = fr"{OUTPUT_PATH}/{user_id}/{task.id}/{topic}/Paper"
    directory = fr"{file_path_prefix}/compression"

    task_id = pdf2md_mineruapi(file_path=paper_pdf_path, topic=topic, user_id=user_id, task=task)

    # 匹配任意数量的#号开头后跟References（不区分大小写）及其后所有内容
    pattern = r'#{0,}\s*References.*'

    if task_id != 0:
        paper_content = read_markdown_file(file_path=fr"{file_path_prefix}/markdown/{task_id}.md")
        paper_content = re.sub(pattern, '', paper_content, flags=re.DOTALL | re.IGNORECASE)
    else:
        return 'None'
    system_prompt = paper_compression_prompt()

    # compression_result = call_with_deepseek(question=f"The content is '''{paper_content}'''",system_prompt=system_prompt)
    compression_result = call_with_qwenmax(question=f"The content is '''{paper_content}'''",
                                           system_prompt=system_prompt)

    # directory = fr"{OUTPUT_PATH}/{topic}/Paper/compression"
    if not os.path.exists(directory):
        os.makedirs(directory)

    with open(fr"{directory}/{task_id}.md", 'w', encoding='utf-8') as f:
        f.write(compression_result)

    return compression_result


def search_releated_paper(topic, max_paper_num=5, compression=True, user_id="", task=None):
    keynum = 0
    relatedPaper = []
    Entities = []

    papers = search_paper(Keywords=[topic], Limit=max_paper_num)

    for paper in papers:
        if compression:
            try:
                print(f"\033[1;32m | INFO     | Getting compressed paper information: {paper['title']} \033[0m")
                compression_result = paper_compression(doi=paper["doi"], title=paper["title"], topic=topic, user_id=user_id, task=task)
                print(
                    f"\033[1;32m | INFO     | Getting compressed paper information: {paper['title']} State: OK! \033[0m")
            except Exception as e:
                print(f"\033[1;31m | ERRO     | compressed paper information: {paper['title']} State: Miss! \033[0m")
                print(f"\033[1;31m | ERROR    | Error details: {str(e)} \033[0m")
                print(f"\033[1;31m | ERROR    | Error type: {type(e).__name__} \033[0m")
                compression_result = "None"
        else:
            compression_result = "None"

        try:
            relatedPaper.append({
                "title": paper["title"],
                "abstract": paper["abstract"],
                "compression_result": compression_result
            })

            for keyword in paper["keyword"]:
                Entities.append(keyword)
        except:
            pass

    Keywords = \
        call_with_deepseek_jsonout(system_prompt=extract_entity_prompt(), question=f"""The content is: {Entities}.""")[
            'keywords']

    keyword_str = ""

    print(f"\033[1;32m | INFO     | Analyzing and processing Keywords:\n{Keywords}\n \033[0m")

    for keyword in Keywords:
        keynum += 1
        temp = get_description(search(query=keyword))
        if not temp:
            print(f"\033[1;31m | Warning     | {keyword}'s description  is empty \033[0m")
            keyword_str += f"{keyword};\n"
        else:
            keyword_str += f"{keyword}:{temp[0]};\n"
    # 可能keyword解释会有问题
    print(f"\033[1;32m | INFO     | Analyzing and processing Keywords' Result:\n{keyword_str}\n \033[0m")

    return keynum, relatedPaper, keyword_str


def extract_message(file, split_section):
    print(f"\033[1;32m | INFO     | extracting message... \033[0m")
    text = read_markdown_file(file)

    if split_section != "":
        match = re.search(fr'### \S*{split_section}\S*(.*?)(?=###|---|\Z)', text, re.DOTALL)
        if match:
            problem_statement = match.group(1).strip()
            print(problem_statement)
    return text, problem_statement


def extract_technical_entities(file, split_section):
    print(f"\033[1;32m | INFO     | extracting technical entities... \033[0m")

    text, problem_statement = extract_message(file, split_section)

    system_prompt = extract_tec_entities_prompt()

    Keywords = call_with_deepseek_jsonout(system_prompt=system_prompt, question=f'The content is: {problem_statement}')[
        'keywords']

    sorted_entities = SearchKeyWordScore(Keywords)

    print(f"\033[1;32m | INFO     | extracting technical entities:OK! \033[0m")

    return sorted_entities, text


def extract_message_review(file, split_section):
    print(f"\033[1;32m | INFO     | Info: extracting message review... \033[0m")
    text = read_markdown_file(file)

    if split_section != "":
        match = re.search(fr'(#.*{split_section}\**\:*)(.*?)(?=#|\Z|---)', text, re.DOTALL)
        if match:
            problem_statement = match.group(2).strip()
        else:
            print(f"\033[1;31m | ERRO     | extracting message review：erro！\033[0m")

    if split_section == "Iterative Optimization Search Keywords":
        question = f"""Based on the content provided below, extract the next optimization search keywords. Return the 
        result only in the following JSON format. Do not add any explanations or irrelevant information. JSON output 
        format: {{ "optimization_keyword": "xxx", ... }}

        Content to extract:
        '''
        #{split_section}\n{problem_statement}
        '''"""
    elif split_section == "Next Steps for Optimization":
        question = f"""Based on the content provided below, extract the next optimization goal. Return the result 
        only in the following JSON format. Do not add any explanations or irrelevant information. JSON output format: 
        {{ "optimization_goal": "xxx", ... }}

        Content to extract:
        '''
        #{split_section}\n{problem_statement}
        '''"""
    else:
        print(split_section)

    result = call_with_deepseek_jsonout(question=question, system_prompt="")
    print(result)

    return text, result


def review_mechanism(topic, draft="", user_id="", task=None):
    # system_prompt = "You are a helpful assistant."
    print(f"\033[1;32m | INFO     | now review is running... \033[0m")

    system_prompt = review_mechanism_prompt()

    user_prompt = f"""# Idea Draft\n{draft}"""

    result = call_with_qwenmax(system_prompt=system_prompt, question=user_prompt)
    file_path_prefix = fr"{OUTPUT_PATH}/{user_id}/{task.id}/{topic}/Review"
    # 检查目录是否存在，不存在则创建
    os.makedirs(file_path_prefix, exist_ok=True)
    with open(fr"{file_path_prefix}/{topic}_review.md", 'w', encoding='utf-8') as f:
        f.write(result)

    text, optimize_messages = extract_message_review(file=fr"{file_path_prefix}/{topic}_review.md",
                                                     split_section="Iterative Optimization Search Keywords")

    keywords = []

    for optimize_message in optimize_messages.values():
        # temp=optimize_message.split('\n')
        # print(temp)
        keywords.append({'keyword': optimize_message})

    print(keywords)

    print(f"\033[1;32m | INFO     | now review is running:OK! \033[0m")

    return keywords


def extract_message_review_moa(file, split_section):
    print(f"\033[1;32m | INFO     | Info: extracting message review... \033[0m")
    text = read_markdown_file(file)

    if split_section != "":
        match = re.search(fr'(#.*{split_section}\**\:*)(.*?)(?=#|\Z|---)', text, re.DOTALL)
        if match:
            problem_statement = match.group(2).strip().split('\n')
            print(problem_statement)
        else:
            print(f"\033[1;31m | ERRO     | extracting message review：erro！\033[0m")
    return text, problem_statement



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2025/8/21 12:04
# @Author : 桐
# @QQ:1041264242
# 注意事项：
"""
该文件用于调用PDF转换为Markdown格式的方法
"""

from app.core.config import MinerU_Token, OUTPUT_PATH
import re
import time
import zipfile
import pandas as pd
import requests
import os


def download_zip_file(url, zip_save_path):
    response = requests.get(url)
    if response.status_code == 200:
        with open(zip_save_path, 'wb') as file:
            file.write(response.content)
        print(f"ZIP 文件已下载到: {zip_save_path}")
    else:
        print(f"无法下载 ZIP 文件，状态码: {response.status_code}")


def find_md_files_in_zip(zip_path, copy_path, batch_id):
    md_files = []
    with zipfile.ZipFile(zip_path, 'r') as zip_ref:
        for file in zip_ref.namelist():
            if file.endswith('.md'):
                md_files.append(file)
        if md_files:
            print("在 ZIP 文件中找到的 MD 文件")
            for md_file in md_files:
                # 提取文件到指定目录
                extracted_path = zip_ref.extract(md_file, copy_path)
                # 重命名文件
                new_file_path = os.path.join(copy_path, batch_id)
                os.rename(extracted_path, new_file_path)
                print(f"已提取并重命名为: {new_file_path}")
        else:
            print("ZIP 文件中没有找到 MD 文件")
    return md_files


def extract_pdf_name(path):
    # 使用正则表达式提取 PDF 文件名称
    match = re.search(r"([^\\]+)\.pdf$", path, re.IGNORECASE)

    if match:
        pdf_name = match.group(1)
        print("提取的 PDF 文件名称:", pdf_name)
    else:
        print("未找到 PDF 文件名称")
    return pdf_name


def download_file_mineruapi(batch_id, topic, user_id, task):
    file_path_prefix = fr"{OUTPUT_PATH}/{user_id}/{task.id}/{topic}/Paper"
    while True:
        url = f'https://mineru.net/api/v4/extract-results/batch/{batch_id}'
        token = MinerU_Token
        header = {
            'Content-Type': 'application/json',
            "Authorization": f"Bearer {token}"
        }
        res = requests.get(url, headers=header)
        print(res.json())

        if res.json()["data"]["extract_result"][0]["state"] == "done":
            # 文件转换成功，保存base64编码的数据到文件
            directory = fr"{file_path_prefix}/markdown"
            zip_dir = fr"{file_path_prefix}/zip"
            if not os.path.exists(directory):
                os.makedirs(directory)
            if not os.path.exists(zip_dir):
                os.makedirs(zip_dir)

            download_zip_file(url=res.json()["data"]["extract_result"][0]["full_zip_url"],
                              zip_save_path=zip_dir + fr"/{batch_id}.zip")
            find_md_files_in_zip(zip_path=zip_dir + f"/{batch_id}.zip", copy_path=directory, batch_id=f"{batch_id}.md")
            break

        elif res.json()["data"]["extract_result"][0]["state"] == "waiting-file" or res.json()["data"][0][
            "state"] == "running":
            print("File is still processing or waiting. Retrying in 5 seconds...")
            time.sleep(5)  # 等待5秒后重试
        else:
            print("Error downloading file:", res.json()["data"]["state"], "batch_id:", batch_id)
            break


def pdf2md_mineruapi(file_path, topic, user_id, task):
    # 读取 Excel 文件，如果不存在则创建
    down_history = fr"{OUTPUT_PATH}/{user_id}/{task.id}/{topic}/down_history.xlsx"
    # 检查目录是否存在，不存在则创建
    os.makedirs(os.path.dirname(down_history), exist_ok=True)
    # 检查文件是否存在，不存在则创建空的DataFrame并保存为Excel
    if not os.path.exists(down_history):
        pd.DataFrame().to_excel(down_history, index=False)
    df = pd.read_excel(down_history)
    pdf_name = extract_pdf_name(path=file_path)
    # 遍历每一行
    for index, row in df.iterrows():
        if row['Paper'] == pdf_name:
            download_file_mineruapi(batch_id=row['Batch_ID'], topic=topic, user_id=user_id, task=task)
            return row['Batch_ID']

    url = 'https://mineru.net/api/v4/file-urls/batch'
    token = MinerU_Token
    header = {
        'Content-Type': 'application/json',
        "Authorization": f"Bearer {token}"
    }
    data = {
        "enable_formula": True,
        "language": "en",
        "layout_model": "doclayout_yolo",
        "enable_table": True,
        "files": [
            {"name": file_path, "is_ocr": True, "data_id": "abcd"}
        ]
    }
    try:
        response = requests.post(url, headers=header, json=data)
        if response.status_code == 200:
            result = response.json()
            if result["code"] == 0:
                batch_id = result["data"]["batch_id"]
                urls = result["data"]["file_urls"]

                with open(file_path, 'rb') as f:
                    res_upload = requests.put(urls[0], data=f)

                if res_upload.status_code == 200:
                    print("upload success")
                else:
                    print("upload failed")
                download_file_mineruapi(batch_id=batch_id, topic=topic, user_id=user_id, task=task)
                # 创建新行的数据（假设你要添加一行数据）
                new_row = {'Paper': pdf_name, 'Batch_ID': batch_id}  # 替换为你的新行数据
                # 将新行添加到 DataFrame 中
                df = pd.concat([df, pd.DataFrame([new_row])], ignore_index=True)
                # 保存修改后的 DataFrame 回原始文件
                df.to_excel(down_history, index=False)
                return batch_id
            else:
                print('apply upload url failed,reason:{}'.format(result.msg))
        else:
            print('response not success. status:{} ,result:{}'.format(response.status_code, response))
    except Exception as err:
        print(err)

    return 0

# print(pdf2md_mineruapi(file_path="..\\Temp\\pulsar candidate classification\\Paper\\pdf\\AnomalyR1_ A GRPO-based End-to-end MLLM for Industrial Anomaly Detection.pdf",topic="pulsar candidate classification"))



"""
Paper API class for AstroInsight
"""

import logging
from typing import Any, Dict, Optional

from ..core.astroinsight import AstroInsight
from ..core.config import AstroInsightConfig

logger = logging.getLogger(__name__)


class PaperAPI:
    """论文API封装类 - 提供论文生成的API接口"""

    def __init__(self, api_config: Optional[Dict[str, Any]] = None):
        """
        初始化PaperAPI

        Args:
            api_config: API配置字典
        """
        self.api_config = api_config or {}
        logger.info("PaperAPI initialized")

    def generate_paper(
        self, keyword: str, search_paper_num: int = 2, **kwargs
    ) -> Dict[str, Any]:
        """
        生成论文API

        Args:
            keyword: 研究关键词
            search_paper_num: 搜索论文数量
            **kwargs: 其他配置参数

        Returns:
            API响应字典

        Example:
            >>> api = PaperAPI()
            >>> response = api.generate_paper("machine learning", 3)
            >>> print(f"Success: {response['success']}")
        """
        try:
            logger.info(f"API: Starting paper generation for keyword: {keyword}")

            # 创建配置
            config = AstroInsightConfig(
                keyword=keyword, search_paper_num=search_paper_num, **kwargs
            )

            # 创建AstroInsight实例
            astro = AstroInsight(config)

            # 执行生成
            result = astro.generate_paper()

            logger.info(f"API: Paper generation completed successfully")

            return {
                "success": True,
                "data": {
                    "task_id": result.get("task_id"),
                    "status": result.get("status"),
                    "steps": result.get("steps", []),
                    "result_file": result.get("result_file", ""),
                    "keyword": keyword,
                    "search_paper_num": search_paper_num,
                },
                "message": "论文生成任务已创建并完成",
            }

        except Exception as e:
            logger.error(f"API: Paper generation failed: {str(e)}")

            return {
                "success": False,
                "error": str(e),
                "message": "论文生成失败",
                "data": {"keyword": keyword, "search_paper_num": search_paper_num},
            }

    def generate_paper_async(
        self, keyword: str, search_paper_num: int = 2, **kwargs
    ) -> Dict[str, Any]:
        """
        异步生成论文API（立即返回任务ID）

        Args:
            keyword: 研究关键词
            search_paper_num: 搜索论文数量
            **kwargs: 其他配置参数

        Returns:
            API响应字典
        """
        try:
            logger.info(f"API: Starting async paper generation for keyword: {keyword}")

            # 创建配置
            config = AstroInsightConfig(
                keyword=keyword, search_paper_num=search_paper_num, **kwargs
            )

            # 创建AstroInsight实例
            astro = AstroInsight(config)

            logger.info(f"API: Async paper generation task created")

            return {
                "success": True,
                "data": {
                    "task_id": astro.task_id,
                    "status": "created",
                    "keyword": keyword,
                    "search_paper_num": search_paper_num,
                },
                "message": "异步论文生成任务已创建",
            }

        except Exception as e:
            logger.error(f"API: Async paper generation failed: {str(e)}")

            return {
                "success": False,
                "error": str(e),
                "message": "异步论文生成任务创建失败",
                "data": {"keyword": keyword, "search_paper_num": search_paper_num},
            }

    def get_status(self, task_id: str) -> Dict[str, Any]:
        """
        获取任务状态API

        Args:
            task_id: 任务ID

        Returns:
            API响应字典
        """
        try:
            logger.info(f"API: Getting status for task: {task_id}")

            # 这里应该实现任务状态查询逻辑
            # 暂时返回模拟状态
            return {
                "success": True,
                "data": {
                    "task_id": task_id,
                    "status": "completed",
                    "message": "任务已完成",
                },
            }

        except Exception as e:
            logger.error(f"API: Failed to get status for task {task_id}: {str(e)}")

            return {
                "success": False,
                "error": str(e),
                "message": "获取任务状态失败",
                "data": {"task_id": task_id},
            }



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2025/8/23 10:33
# @Author : 桐
# @QQ:1041264242
# 注意事项：
from openai import OpenAI
from py2neo import Graph
from pydantic_settings import BaseSettings, SettingsConfigDict

class Settings(BaseSettings):
    model_config = SettingsConfigDict(
        # Use top level .env file (one level above ./backend/)
        env_file=".env",
        env_ignore_empty=True,
        extra="ignore",
    )

    # 本项目配置
    MINERU_API_TOKEN: str = ""
    QWEN_API_TOKEN: str = ""
    DEEPSEEK_API_TOKEN: str = ""
    DEEPSEEK_API_BASE_URL: str = "https://api.deepseek.com/v1"
    NEO4J_USERNAME: str = ""
    NEO4J_PASSWORD: str = ""
    NEO4J_HOST: str = ""
    NEO4J_PORT: str = ""
    PAPER_ASSISTANT_OUTPUT_PATH: str = "./temp"

    # 数据库配置
    DB_SERVER: str = "127.0.0.1"
    DB_USER: str = ""
    DB_PORT: int = 3306
    DB_PASSWORD: str = ""
    DB_DBNAME: str = ""

    # redis配置
    REDIS_SERVER: str = "127.0.0.1"
    REDIS_PORT: int = 6379
    REDIS_PASSWORD: str = ""
    REDIS_DB_INDEX: int = 0

settings = Settings()

OUTPUT_PATH=settings.PAPER_ASSISTANT_OUTPUT_PATH #这里为结果文件输出路径

#MinerU Token配置
MinerU_Token=settings.MINERU_API_TOKEN

# 代理地址配置
Proxies = {
    'http': 'http://192.168.2.23:7897',
    'https': 'http://192.168.2.23:7897'
}

#大模型API配置
DeepSeek_Key=OpenAI(api_key=settings.DEEPSEEK_API_TOKEN, base_url=settings.DEEPSEEK_API_BASE_URL)
QwenMax_Key=settings.QWEN_API_TOKEN

#neo4j 实体库接口配置
neo4j_url = f"bolt://{settings.NEO4J_HOST}:{settings.NEO4J_PORT}"
neo4j_username = settings.NEO4J_USERNAME
neo4j_password = settings.NEO4J_PASSWORD
graph = Graph(neo4j_url, auth=(neo4j_username, neo4j_password))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2024/9/21 23:07
# @Author : 桐
# @QQ:1041264242
# 注意事项：
import arxiv
import json


def get_authors(authors, first_author=False):
    if not first_author:
        output = ", ".join(str(author) for author in authors)
    else:
        output = authors[0]
    return output


def get_papers(query="astronomy", max_results=2):
    """
    @param topic: str
    @param query: str
    @return paper_with_code: dict
    """

    paper_list = []

    search_engine = arxiv.Search(
        query=query,
        max_results=max_results,
        sort_by=arxiv.SortCriterion.Relevance
    )

    for result in search_engine.results():
        paper_id = result.entry_id
        paper_title = result.title
        paper_pdf = result.pdf_url
        paper_doi = result.doi
        paper_abstract = result.summary.replace("\n", " ")
        paper_authors = get_authors(result.authors)
        primary_category = result.primary_category
        publish_time = result.published.date().isoformat()

        data = {"topic": query,
                "title": paper_title,
                "id": paper_id,
                "doi": paper_doi,
                "pdf": paper_pdf,
                "abstract": paper_abstract,
                "authors": paper_authors,
                "category": primary_category,
                "time": publish_time}

        paper_list.append(data)

    return paper_list


def search_paper(Keywords, Limit=2):
    data_collector = []

    for keyword in Keywords:
        print(f"Info: retrieve papers related to technical entities...")
        data_collector += get_papers(query=keyword, max_results=Limit)
        print(json.dumps(data_collector, indent=4))
        print(f"Info: retrieve papers related to technical entities: {keyword} State:OK!")
    return data_collector



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2025/8/19 15:44
# @Author : 桐
# @QQ:1041264242
# 注意事项：
"""
该文件用于调用大模型API
"""

import json
import tiktoken
from app.core.prompt import llm_base_prompt
from app.core.config import DeepSeek_Key, QwenMax_Key
import dashscope
from http import HTTPStatus

# 假设DeepSeekV2模型的定价是每个token 0.0001美元
TOKEN_PRICE_USD = 0.0001
total_tokens_used = 0


def calculate_token_cost(content, model_name="gpt-3.5-turbo"):
    # 使用tiktoken库来计算token数量
    enc = tiktoken.encoding_for_model(model_name)
    tokens = enc.encode(content)
    token_count = len(tokens)
    # 计算费用
    cost_usd = token_count * TOKEN_PRICE_USD
    global total_tokens_used
    total_tokens_used += token_count
    print(f"\033[1;32m | INFO     | Have used total tokens：{total_tokens_used} \033[0m")
    return token_count, cost_usd


def call_with_deepseek(question, system_prompt=llm_base_prompt(), temperature=0.7):
    client = DeepSeek_Key
    messages = [
        {"role": "system", "content": system_prompt},
        {"role": "user", "content": question},
    ]

    response = client.chat.completions.create(
        model="deepseek-chat",
        temperature=temperature,
        messages=messages
    )

    calculate_token_cost(content=question + system_prompt + response.choices[0].message.content)

    print("\033[1;32m | INFO     | Call_with_deepseek: OK! \033[0m")
    return response.choices[0].message.content


def call_with_deepseek_jsonout(system_prompt, question):
    client = DeepSeek_Key

    if system_prompt == "":
        system_prompt = """The user will provide some exam text. Please parse the "question" and "answer" and output them in JSON format. 

EXAMPLE INPUT: 
Which is the highest mountain in the world? Mount Everest.

EXAMPLE JSON OUTPUT:
{
    "question": "Which is the highest mountain in the world?",
    "answer": "Mount Everest"
}"""

    messages = [
        {"role": "system", "content": system_prompt},
        {"role": "user", "content": question},
    ]

    response = client.chat.completions.create(
        model="deepseek-chat",
        messages=messages,
        response_format={
            'type': 'json_object'
        }
    )
    calculate_token_cost(content=question + system_prompt + response.choices[0].message.content)
    return json.loads(response.choices[0].message.content)


def call_with_qwenmax(question, system_prompt=llm_base_prompt()):
    messages = [
        {"role": "system", "content": system_prompt},
        {"role": "user", "content": question},
    ]

    responses = dashscope.Generation.call(
        model="qwen-max-2025-01-25",
        api_key=QwenMax_Key,
        messages=messages,
        stream=False,
        result_format='message',  # 将返回结果格式设置为 message
        top_p=0.8,
        temperature=0.7,
        enable_search=False
    )

    if responses.status_code == HTTPStatus.OK:
        print(responses.output.choices[0].message.content)
    else:
        print('Request id: %s, Status code: %s, error code: %s, error message: %s' % (
            responses.request_id, responses.status_code,
            responses.code, responses.message
        ))

    print("\033[1;32m  call_with_qwenmax ok! \033[0m")
    return responses.output.choices[0].message.content



from setuptools import find_packages, setup


# 读取README文件
def read_readme():
    with open("README.md", "r", encoding="utf-8") as fh:
        return fh.read()


# 读取requirements.txt
def read_requirements():
    try:
        with open("requirements-minimal.txt", "r", encoding="utf-8") as fh:
            return [
                line.strip()
                for line in fh
                if line.strip() and not line.strip().startswith("#")
            ]
    except FileNotFoundError:
        # 如果找不到最小化版本，回退到原始版本
        with open("requirements.txt", "r", encoding="utf-8") as fh:
            return [
                line.strip()
                for line in fh
                if (
                    line.strip()
                    and not line.strip().startswith("#")
                    and not line.strip().startswith("-e")
                )
            ]


setup(
    name="astroinsight",
    version="0.1.0",
    author="AstroInsight Team",
    author_email="contact@astroinsight.com",
    description=("AI-powered research paper assistant with multi-agent collaboration"),
    long_description=read_readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/astroinsight",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Scientific/Engineering :: Information Analysis",
    ],
    python_requires=">=3.8",
    install_requires=read_requirements(),
    extras_require={
        "dev": [
            "pytest>=7.0.0",
            "black>=24.10.0",
            "flake8>=7.1.1",
            "mypy>=1.0.0",
            "twine>=4.0.0",
            "wheel>=0.40.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "astroinsight=astroinsight.cli:main",
        ],
    },
    include_package_data=True,
    package_data={
        "astroinsight": ["templates/**/*", "config/*.yaml"],
    },
    keywords="ai, research, paper, multi-agent, collaboration, astroinsight",
    project_urls={
        "Bug Reports": "https://github.com/yourusername/astroinsight/issues",
        "Source": "https://github.com/yourusername/astroinsight",
        "Documentation": "https://astroinsight.readthedocs.io/",
    },
)



from celery import Celery

from app.core.config import settings

celery_dbname = "uniplore_va_ai"
result_backend_store = f"db+mysql://{settings.DB_USER}:{settings.DB_PASSWORD}@{settings.DB_SERVER}:{settings.DB_PORT}/{celery_dbname}"

redis_db_index = 5
broker_store = f"redis://:{settings.REDIS_PASSWORD}@{settings.REDIS_SERVER}:{settings.REDIS_PORT}/{redis_db_index}"
celery_app = Celery('tasks', broker=broker_store, result_backend=result_backend_store)
